core/models/layers/layer library

Classes

EmojiLayer
A class representing a layer with emoji content.
Layer
Represents a layer with common properties for widgets.
LayerAnimation
A single animation applied to a Layer on the video timeline.
PaintLayer
A class representing a layer with custom paint content.
TextLayer
Represents a text layer with customizable properties.
WidgetLayer
A class representing a layer with custom widget content.
WidgetLayerExportConfigs
A class that represents the export configurations for a widget layer.

Enums

AnimationCurve
Easing curve for animation timing.
AnimationPhase
Whether the animation plays at the start, end, or both ends of the layer's time range.
LayerAnimationType
The type of animation to apply to a Layer.
SlideDirection
Slide direction for slide animations.

Typedefs

LayerTimelineTransitionBuilder = Widget Function(Widget child, Animation<double> animation)
Signature for a builder that wraps a layer widget with an animated transition driven by animation.