GestureManager class

A singleton class to manage gesture propagation in the app.

Use GestureManager.instance to access the singleton.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isBlocked → bool
Returns true if gesture propagation is currently blocked.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stopPropagation() → void
Temporarily blocks pointer events from reaching widgets below in the image editor.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → GestureManager
The single instance of GestureManager.
final