VideoClip class

Model representing an video-clip with metadata.

Constructors

VideoClip({required String id, required String title, String? subtitle, EditorImage? image, required EditorVideoClip clip, required Duration duration, TrimDurationSpan? trimSpan, List<ImageProvider<Object>>? thumbnails})
Creates an instance of VideoClip.

Properties

clip → EditorVideoClip
Video-Clip source that should be played for this track.
final
duration → Duration
The total duration of the video clip.
final
hashCode → int
The hash code for this object.
no setteroverride
id → String
Unique identifier for the clip.
final
image → EditorImage?
Optional thumbnail from the video-clip.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → String?
Subtitle of the clip.
final
thumbnails ↔ List<ImageProvider<Object>>?
Cached thumbnail images representing the video clip.
getter/setter pair
title → String
Name/title of the clip.
final
trimSpan ↔ TrimDurationSpan?
The selected trim range within the video clip.
getter/setter pair

Methods

copyWith({String? id, String? title, String? subtitle, EditorImage? image, EditorVideoClip? clip, Duration? duration, TrimDurationSpan? trimSpan, List<ImageProvider<Object>>? thumbnails}) → VideoClip
Creates a copy of this VideoClip with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override