DeferredPointerHandlerLink class

Holds a list of DeferPointerRenderObjects which the DeferredPointerHandler widget uses to perform hit tests.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
painters → List<DeferPointerRenderObject>
All painters currently attached to this link
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(DeferPointerRenderObject value) → void
Add a render object to the link. Does nothing if item already exists.
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
descendantNeedsPaint() → void
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
remove(DeferPointerRenderObject value) → void
Remove a render object from the link. Does nothing if item is not in list.
removeAll() → void
Clears all currently attached links
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited