Config class

Config for customizations

Constructors

Config({double height = 256, bool checkPlatformCompatibility = true, List<CategoryEmoji> emojiSet(Locale locale)? = getDefaultEmojiLocale, Locale locale = const Locale('en'), TextStyle? emojiTextStyle, Icon? customBackspaceIcon, Icon? customSearchIcon, ViewOrderConfig viewOrderConfig = const ViewOrderConfig(), EmojiViewConfig emojiViewConfig = const EmojiViewConfig(), SkinToneConfig skinToneConfig = const SkinToneConfig(), CategoryViewConfig categoryViewConfig = const CategoryViewConfig(), BottomActionBarConfig bottomActionBarConfig = const BottomActionBarConfig(), SearchViewConfig searchViewConfig = const SearchViewConfig()})
Constructor
const

Properties

bottomActionBarConfig → BottomActionBarConfig
Search bar config
final
categoryViewConfig → CategoryViewConfig
Category view config
final
checkPlatformCompatibility → bool
Verify that emoji glyph is supported by the platform (Android only)
final
customBackspaceIcon → Icon?
Custom backspace icon
final
customSearchIcon → Icon?
Custom search icon
final
emojiSet → List<CategoryEmoji> Function(Locale locale)?
Useful to provide a customized list of Emoji or add/remove the support for specific locales (create similar method as in default_emoji_set_locale.dart). If not provided, the default emoji set will be used based on the locales that are available in the package.
final
emojiTextStyle → TextStyle?
Custom emoji text style to apply to emoji characters in the grid
final
emojiViewConfig → EmojiViewConfig
Emoji view config
final
hashCode → int
The hash code for this object.
no setteroverride
height → double
Max Height of the Emoji's view
final
locale → Locale
Locale to choose the fitting language for the emoji set This will affect the emoji search results
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchViewConfig → SearchViewConfig
Search View config
final
skinToneConfig → SkinToneConfig
Skin tone config
final
viewOrderConfig → ViewOrderConfig
Config the order of the views displayed in the UI (category bar, emoji view, search bar)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override