WinEncoder class abstract

Inheritance
Implementers

Constructors

WinEncoder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsAnimation → bool
True if the encoder supports animated Images; otherwise false.
no setteroverride
type → int
no setter

Methods

bitsPerPixelOrYHotSpot(int index) → int
colorPlanesOrXHotSpot(int index) → int
encode(Image image, {bool singleFrame = false}) → Uint8List
Encode an image to an image format. If singleFrame is true, only the one Image will be encoded; otherwise if image has animation, all frames of the image will be encoded if the encoder supports animation.
override
encodeImages(List<Image> images) → Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited