IccProfile class

ICC Profile data stored with an image.

Constructors

IccProfile(String name, IccProfileCompression compression, Uint8List data)
IccProfile.from(IccProfile other)

Properties

compression ↔ IccProfileCompression
getter/setter pair
data ↔ Uint8List
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clone() → IccProfile
compressed() → Uint8List
Returns the compressed data of the ICC Profile, compressing the stored data as necessary.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited