Rational class

Represents a floating-point number in rational form of numerator and denominator.

Constructors

Rational(int numerator, int denominator)

Properties

denominator ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
numerator ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
simplify() → void
toDouble() → double
toInt() → int
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override