MagicNumber class

Constructors

MagicNumber(String mimeType, List<int> numbers, {List<int>? mask})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
mask → List<int>?
final
mimeType → String
final
numbers → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

matches(List<int> header) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited