LayerRasterizationRequest class

A pending rasterization, handed to a LayerRasterizerHost so it can mount the layers that LayerRasterizer.capture is waiting on.

Annotations

Constructors

LayerRasterizationRequest({required List<Layer> layers, required Size editorBodySize, required ProImageEditorConfigs configs})
Creates a request for layers laid out against editorBodySize.
const

Properties

configs → ProImageEditorConfigs
The editor configuration used to build the layer widgets.
final
editorBodySize → Size
The editor body size the layers were originally laid out against.
final
hashCode → int
The hash code for this object.
no setterinherited
layers → List<Layer>
The layers to mount.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited