ShaderManager class

A singleton class that manages and caches fragment shaders for different modes.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isShaderFilterSupported → bool
Whether ImageFilter.shader is supported on the current backend.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shaders → Map<ShaderMode, FragmentShader>
A map that stores loaded shaders by their mode.
final

Methods

containsShader(ShaderMode mode) → bool
Checks if a shader for the given mode is already loaded.
loadShader(ShaderMode mode) → Future<FragmentShader>
Loads a shader for the given mode. If the shader is already loaded, it returns the cached version. Otherwise, it asynchronously loads and caches the shader.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → ShaderManager
The singleton instance of ShaderManager.
final