isDesktop top-level property
Checks if the app is running on a desktop platform.
Implementation
final isDesktop =
!isWebMobile &&
(kIsWeb || Platform.isMacOS || Platform.isWindows || Platform.isLinux);
Checks if the app is running on a desktop platform.
final isDesktop =
!isWebMobile &&
(kIsWeb || Platform.isMacOS || Platform.isWindows || Platform.isLinux);