shared/widgets/layer/paint_layer_raster_cache_host library

Mixins

PaintLayerRasterCacheHost<T extends StatefulWidget>
Lets the state of a widget that stacks LayerWidgets draw its static paint layers from a PaintLayerRasterCache.