LoadingDialog class

A singleton class that manages the display of loading dialogs.

The LoadingDialog class provides methods to show and hide a loading dialog. It allows customization of the loading message, dismissibility, and theme. It maintains a stack of active overlays to handle multiple dialogs if needed.

Inheritance

Properties

hasActiveOverlay → bool
Returns true if there is an active overlay.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
isDismissible → bool
Returns true if the topmost overlay is dismissible.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
hide() → void
Hides the topmost loading dialog.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
show(BuildContext context, {String? message, bool isDismissible = kDebugMode, ThemeData? theme, required ProImageEditorConfigs configs}) → void
Displays a loading dialog in the given context.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → LoadingDialog
The singleton instance of LoadingDialog.
final