core/models/layers/layer library

Classes

EmojiLayer
A class representing a layer with emoji content.
Layer
Represents a layer with common properties for widgets.
PaintLayer
A class representing a layer with custom paint content.
TextLayer
Represents a text layer with customizable properties.
WidgetLayer
A class representing a layer with custom widget content.
WidgetLayerExportConfigs
A class that represents the export configurations for a widget layer.

Typedefs

LayerTimelineTransitionBuilder = Widget Function(Widget child, Animation<double> animation)
Signature for a builder that wraps a layer widget with an animated transition driven by animation.